# Table of Contents

- [ai-agent-extension-to-meta-model](<./ai-agent-extension-to-meta-model.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [AI Agent Extension to the Meta Model](<./AI-Agent-Extension-to-the-Meta-Model.md>)
  - [Overview](<./AI-Agent-Extension-to-the-Meta-Model/Overview.md>)
  - [Before You Start](<./AI-Agent-Extension-to-the-Meta-Model/Before-You-Start.md>)
  - [Activating the Extension](<./AI-Agent-Extension-to-the-Meta-Model/Activating-the-Extension.md>)
  - [Changes Introduced with the Extension](<./AI-Agent-Extension-to-the-Meta-Model/Changes-Introduced-with-the-Extension.md>)
  - [Scenarios for Application Subtypes](<./AI-Agent-Extension-to-the-Meta-Model/Scenarios-for-Application-Subtypes.md>)
  - [Compatibility with Other Extensions](<./AI-Agent-Extension-to-the-Meta-Model/Compatibility-with-Other-Extensions.md>)
  - [AI Agent Fact Sheet Subtype](<./AI-Agent-Extension-to-the-Meta-Model/AI-Agent-Fact-Sheet-Subtype.md>)
  - [Business Application Fact Sheet Subtype](<./AI-Agent-Extension-to-the-Meta-Model/Business-Application-Fact-Sheet-Subtype.md>)
  - [MCP Server Fact Sheet Subtype](<./AI-Agent-Extension-to-the-Meta-Model/MCP-Server-Fact-Sheet-Subtype.md>)
  - [API Fact Sheet Subtype](<./AI-Agent-Extension-to-the-Meta-Model/API-Fact-Sheet-Subtype.md>)
  - [Relations](<./AI-Agent-Extension-to-the-Meta-Model/Relations.md>)
